function x=lsqlc(A,b,C,d,tol)
%
% Solves the linearly-constrained least squares problem 
%      
%      Min ||Ax-b||
%     Cx=d
%
% Input arguments:
%  A, C - mxn and pxn matrices,
%  b, d - mx1 and px1 vectors
%  tol  - tolerance (see the assignment for details)
%
% Output argument:
%   x   - nx1 vector, solution (if no solution exists, x=NaN)
 
[U,S,V]=svd(C);
sc=size(S,2);
S=S.*(S>=tol);
k=rank(S);
a=U'*d;
a=a.*(abs(a)>tol);
v=zeros(k,1);
if (sum((a(k+1:end))>0))
    x=NaN;
    return
end
for i=1:k
    if (S(i,i)~=0)
        v(i)=a(i)/S(i,i);
    end
end
v=[v;zeros(size(V,1)-k,1)];
x0=V*v;
b2=b-A*x0;
G=A*V;
G=G(:,k+1:end);
u=pinv(G,tol)*b2;
z=[zeros(k,1);u];
x=x0+V*z;